v0

package
v0.2.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 27, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	Tooling_Fix_FullMethodName              = "/codefly.services.tooling.v0.Tooling/Fix"
	Tooling_ApplyEdit_FullMethodName        = "/codefly.services.tooling.v0.Tooling/ApplyEdit"
	Tooling_ListDependencies_FullMethodName = "/codefly.services.tooling.v0.Tooling/ListDependencies"
	Tooling_AddDependency_FullMethodName    = "/codefly.services.tooling.v0.Tooling/AddDependency"
	Tooling_RemoveDependency_FullMethodName = "/codefly.services.tooling.v0.Tooling/RemoveDependency"
	Tooling_GetProjectInfo_FullMethodName   = "/codefly.services.tooling.v0.Tooling/GetProjectInfo"
	Tooling_Build_FullMethodName            = "/codefly.services.tooling.v0.Tooling/Build"
	Tooling_Test_FullMethodName             = "/codefly.services.tooling.v0.Tooling/Test"
	Tooling_Lint_FullMethodName             = "/codefly.services.tooling.v0.Tooling/Lint"
)

Variables

var (
	DiagnosticSeverity_name = map[int32]string{
		0: "DIAGNOSTIC_SEVERITY_UNKNOWN",
		1: "DIAGNOSTIC_SEVERITY_ERROR",
		2: "DIAGNOSTIC_SEVERITY_WARNING",
		3: "DIAGNOSTIC_SEVERITY_INFORMATION",
		4: "DIAGNOSTIC_SEVERITY_HINT",
	}
	DiagnosticSeverity_value = map[string]int32{
		"DIAGNOSTIC_SEVERITY_UNKNOWN":     0,
		"DIAGNOSTIC_SEVERITY_ERROR":       1,
		"DIAGNOSTIC_SEVERITY_WARNING":     2,
		"DIAGNOSTIC_SEVERITY_INFORMATION": 3,
		"DIAGNOSTIC_SEVERITY_HINT":        4,
	}
)

Enum value maps for DiagnosticSeverity.

var File_codefly_services_tooling_v0_tooling_proto protoreflect.FileDescriptor
var Tooling_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "codefly.services.tooling.v0.Tooling",
	HandlerType: (*ToolingServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Fix",
			Handler:    _Tooling_Fix_Handler,
		},
		{
			MethodName: "ApplyEdit",
			Handler:    _Tooling_ApplyEdit_Handler,
		},
		{
			MethodName: "ListDependencies",
			Handler:    _Tooling_ListDependencies_Handler,
		},
		{
			MethodName: "AddDependency",
			Handler:    _Tooling_AddDependency_Handler,
		},
		{
			MethodName: "RemoveDependency",
			Handler:    _Tooling_RemoveDependency_Handler,
		},
		{
			MethodName: "GetProjectInfo",
			Handler:    _Tooling_GetProjectInfo_Handler,
		},
		{
			MethodName: "Build",
			Handler:    _Tooling_Build_Handler,
		},
		{
			MethodName: "Test",
			Handler:    _Tooling_Test_Handler,
		},
		{
			MethodName: "Lint",
			Handler:    _Tooling_Lint_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "codefly/services/tooling/v0/tooling.proto",
}

Tooling_ServiceDesc is the grpc.ServiceDesc for Tooling service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterToolingServer

func RegisterToolingServer(s grpc.ServiceRegistrar, srv ToolingServer)

Types

type AddDependencyRequest

type AddDependencyRequest struct {

	// package_name is the package or dependency identifier used by the native manager.
	PackageName string `protobuf:"bytes,1,opt,name=package_name,json=packageName,proto3" json:"package_name,omitempty"`
	// version is the semantic or service-specific version for this resource.
	Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

AddDependencyRequest identifies a package to install with the native package manager.

func (*AddDependencyRequest) Descriptor deprecated

func (*AddDependencyRequest) Descriptor() ([]byte, []int)

Deprecated: Use AddDependencyRequest.ProtoReflect.Descriptor instead.

func (*AddDependencyRequest) GetPackageName

func (x *AddDependencyRequest) GetPackageName() string

func (*AddDependencyRequest) GetVersion

func (x *AddDependencyRequest) GetVersion() string

func (*AddDependencyRequest) ProtoMessage

func (*AddDependencyRequest) ProtoMessage()

func (*AddDependencyRequest) ProtoReflect

func (x *AddDependencyRequest) ProtoReflect() protoreflect.Message

func (*AddDependencyRequest) Reset

func (x *AddDependencyRequest) Reset()

func (*AddDependencyRequest) String

func (x *AddDependencyRequest) String() string

type AddDependencyResponse

type AddDependencyResponse struct {

	// success is true when the requested operation completed successfully.
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// error explains why the operation failed; empty means success at this layer.
	Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
	// installed_version is the version resolved by the package manager.
	InstalledVersion string `protobuf:"bytes,3,opt,name=installed_version,json=installedVersion,proto3" json:"installed_version,omitempty"`
	// contains filtered or unexported fields
}

AddDependencyResponse reports the dependency version resolved by the package manager.

func (*AddDependencyResponse) Descriptor deprecated

func (*AddDependencyResponse) Descriptor() ([]byte, []int)

Deprecated: Use AddDependencyResponse.ProtoReflect.Descriptor instead.

func (*AddDependencyResponse) GetError

func (x *AddDependencyResponse) GetError() string

func (*AddDependencyResponse) GetInstalledVersion

func (x *AddDependencyResponse) GetInstalledVersion() string

func (*AddDependencyResponse) GetSuccess

func (x *AddDependencyResponse) GetSuccess() bool

func (*AddDependencyResponse) ProtoMessage

func (*AddDependencyResponse) ProtoMessage()

func (*AddDependencyResponse) ProtoReflect

func (x *AddDependencyResponse) ProtoReflect() protoreflect.Message

func (*AddDependencyResponse) Reset

func (x *AddDependencyResponse) Reset()

func (*AddDependencyResponse) String

func (x *AddDependencyResponse) String() string

type ApplyEditRequest

type ApplyEditRequest struct {

	// file is a workspace- or service-relative source file path.
	File string `protobuf:"bytes,1,opt,name=file,proto3" json:"file,omitempty"`
	// find is the text to locate before applying a replacement.
	Find string `protobuf:"bytes,2,opt,name=find,proto3" json:"find,omitempty"`
	// replace is the replacement text inserted by the edit.
	Replace string `protobuf:"bytes,3,opt,name=replace,proto3" json:"replace,omitempty"`
	// auto_fix asks the agent to run formatters after the edit.
	AutoFix bool `protobuf:"varint,4,opt,name=auto_fix,json=autoFix,proto3" json:"auto_fix,omitempty"`
	// contains filtered or unexported fields
}

ApplyEditRequest asks the agent to apply a language-aware find/replace edit.

func (*ApplyEditRequest) Descriptor deprecated

func (*ApplyEditRequest) Descriptor() ([]byte, []int)

Deprecated: Use ApplyEditRequest.ProtoReflect.Descriptor instead.

func (*ApplyEditRequest) GetAutoFix

func (x *ApplyEditRequest) GetAutoFix() bool

func (*ApplyEditRequest) GetFile

func (x *ApplyEditRequest) GetFile() string

func (*ApplyEditRequest) GetFind

func (x *ApplyEditRequest) GetFind() string

func (*ApplyEditRequest) GetReplace

func (x *ApplyEditRequest) GetReplace() string

func (*ApplyEditRequest) ProtoMessage

func (*ApplyEditRequest) ProtoMessage()

func (*ApplyEditRequest) ProtoReflect

func (x *ApplyEditRequest) ProtoReflect() protoreflect.Message

func (*ApplyEditRequest) Reset

func (x *ApplyEditRequest) Reset()

func (*ApplyEditRequest) String

func (x *ApplyEditRequest) String() string

type ApplyEditResponse

type ApplyEditResponse struct {

	// success is true when the requested operation completed successfully.
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// content is the file content after the edit and optional fixers.
	Content string `protobuf:"bytes,2,opt,name=content,proto3" json:"content,omitempty"`
	// error explains why the operation failed; empty means success at this layer.
	Error string `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
	// strategy names the edit or execution strategy that produced the result.
	Strategy string `protobuf:"bytes,4,opt,name=strategy,proto3" json:"strategy,omitempty"`
	// fix_actions names formatters or import fixers that ran after the edit.
	FixActions []string `protobuf:"bytes,5,rep,name=fix_actions,json=fixActions,proto3" json:"fix_actions,omitempty"`
	// contains filtered or unexported fields
}

ApplyEditResponse reports the selected strategy and post-edit content.

func (*ApplyEditResponse) Descriptor deprecated

func (*ApplyEditResponse) Descriptor() ([]byte, []int)

Deprecated: Use ApplyEditResponse.ProtoReflect.Descriptor instead.

func (*ApplyEditResponse) GetContent

func (x *ApplyEditResponse) GetContent() string

func (*ApplyEditResponse) GetError

func (x *ApplyEditResponse) GetError() string

func (*ApplyEditResponse) GetFixActions

func (x *ApplyEditResponse) GetFixActions() []string

func (*ApplyEditResponse) GetStrategy

func (x *ApplyEditResponse) GetStrategy() string

func (*ApplyEditResponse) GetSuccess

func (x *ApplyEditResponse) GetSuccess() bool

func (*ApplyEditResponse) ProtoMessage

func (*ApplyEditResponse) ProtoMessage()

func (*ApplyEditResponse) ProtoReflect

func (x *ApplyEditResponse) ProtoReflect() protoreflect.Message

func (*ApplyEditResponse) Reset

func (x *ApplyEditResponse) Reset()

func (*ApplyEditResponse) String

func (x *ApplyEditResponse) String() string

type BuildRequest

type BuildRequest struct {
	// contains filtered or unexported fields
}

BuildRequest asks the agent to run the native build command.

func (*BuildRequest) Descriptor deprecated

func (*BuildRequest) Descriptor() ([]byte, []int)

Deprecated: Use BuildRequest.ProtoReflect.Descriptor instead.

func (*BuildRequest) ProtoMessage

func (*BuildRequest) ProtoMessage()

func (*BuildRequest) ProtoReflect

func (x *BuildRequest) ProtoReflect() protoreflect.Message

func (*BuildRequest) Reset

func (x *BuildRequest) Reset()

func (*BuildRequest) String

func (x *BuildRequest) String() string

type BuildResponse

type BuildResponse struct {

	// success is true when the requested operation completed successfully.
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// output is raw command, build, lint, or test output preserved for diagnostics.
	Output string `protobuf:"bytes,2,opt,name=output,proto3" json:"output,omitempty"`
	// diagnostics are compiler, linter, or language-server findings.
	Diagnostics []*Diagnostic `protobuf:"bytes,3,rep,name=diagnostics,proto3" json:"diagnostics,omitempty"`
	// contains filtered or unexported fields
}

BuildResponse returns build output and diagnostics from the native toolchain.

func (*BuildResponse) Descriptor deprecated

func (*BuildResponse) Descriptor() ([]byte, []int)

Deprecated: Use BuildResponse.ProtoReflect.Descriptor instead.

func (*BuildResponse) GetDiagnostics

func (x *BuildResponse) GetDiagnostics() []*Diagnostic

func (*BuildResponse) GetOutput

func (x *BuildResponse) GetOutput() string

func (*BuildResponse) GetSuccess

func (x *BuildResponse) GetSuccess() bool

func (*BuildResponse) ProtoMessage

func (*BuildResponse) ProtoMessage()

func (*BuildResponse) ProtoReflect

func (x *BuildResponse) ProtoReflect() protoreflect.Message

func (*BuildResponse) Reset

func (x *BuildResponse) Reset()

func (*BuildResponse) String

func (x *BuildResponse) String() string

type Dependency

type Dependency struct {

	// name is the package, module, or dependency identifier.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// version is the semantic or service-specific version for this resource.
	Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	// direct is true when the dependency is declared directly rather than transitively inferred.
	Direct bool `protobuf:"varint,3,opt,name=direct,proto3" json:"direct,omitempty"`
	// contains filtered or unexported fields
}

Dependency represents a package or module dependency.

func (*Dependency) Descriptor deprecated

func (*Dependency) Descriptor() ([]byte, []int)

Deprecated: Use Dependency.ProtoReflect.Descriptor instead.

func (*Dependency) GetDirect

func (x *Dependency) GetDirect() bool

func (*Dependency) GetName

func (x *Dependency) GetName() string

func (*Dependency) GetVersion

func (x *Dependency) GetVersion() string

func (*Dependency) ProtoMessage

func (*Dependency) ProtoMessage()

func (*Dependency) ProtoReflect

func (x *Dependency) ProtoReflect() protoreflect.Message

func (*Dependency) Reset

func (x *Dependency) Reset()

func (*Dependency) String

func (x *Dependency) String() string

type Diagnostic

type Diagnostic struct {

	// file is a workspace- or service-relative source file path.
	File string `protobuf:"bytes,1,opt,name=file,proto3" json:"file,omitempty"`
	// line is the 1-based source line number.
	Line int32 `protobuf:"varint,2,opt,name=line,proto3" json:"line,omitempty"`
	// column is the 1-based source column number when known.
	Column int32 `protobuf:"varint,3,opt,name=column,proto3" json:"column,omitempty"`
	// end_line is the 1-based ending source line for a range.
	EndLine int32 `protobuf:"varint,4,opt,name=end_line,json=endLine,proto3" json:"end_line,omitempty"`
	// end_column is the 1-based ending source column for a range.
	EndColumn int32 `protobuf:"varint,5,opt,name=end_column,json=endColumn,proto3" json:"end_column,omitempty"`
	// message is the diagnostic text returned by the producing tool.
	Message string `protobuf:"bytes,6,opt,name=message,proto3" json:"message,omitempty"`
	// severity is the diagnostic level such as error, warning, information, or hint.
	Severity DiagnosticSeverity `protobuf:"varint,7,opt,name=severity,proto3,enum=codefly.services.tooling.v0.DiagnosticSeverity" json:"severity,omitempty"`
	// source identifies the tool that produced the diagnostic or event.
	Source string `protobuf:"bytes,8,opt,name=source,proto3" json:"source,omitempty"`
	// code is the diagnostic or rule identifier from the producing tool.
	Code string `protobuf:"bytes,9,opt,name=code,proto3" json:"code,omitempty"`
	// contains filtered or unexported fields
}

Diagnostic represents a compiler, linter, or language-server finding.

func (*Diagnostic) Descriptor deprecated

func (*Diagnostic) Descriptor() ([]byte, []int)

Deprecated: Use Diagnostic.ProtoReflect.Descriptor instead.

func (*Diagnostic) GetCode

func (x *Diagnostic) GetCode() string

func (*Diagnostic) GetColumn

func (x *Diagnostic) GetColumn() int32

func (*Diagnostic) GetEndColumn

func (x *Diagnostic) GetEndColumn() int32

func (*Diagnostic) GetEndLine

func (x *Diagnostic) GetEndLine() int32

func (*Diagnostic) GetFile

func (x *Diagnostic) GetFile() string

func (*Diagnostic) GetLine

func (x *Diagnostic) GetLine() int32

func (*Diagnostic) GetMessage

func (x *Diagnostic) GetMessage() string

func (*Diagnostic) GetSeverity

func (x *Diagnostic) GetSeverity() DiagnosticSeverity

func (*Diagnostic) GetSource

func (x *Diagnostic) GetSource() string

func (*Diagnostic) ProtoMessage

func (*Diagnostic) ProtoMessage()

func (*Diagnostic) ProtoReflect

func (x *Diagnostic) ProtoReflect() protoreflect.Message

func (*Diagnostic) Reset

func (x *Diagnostic) Reset()

func (*Diagnostic) String

func (x *Diagnostic) String() string

type DiagnosticSeverity

type DiagnosticSeverity int32

DiagnosticSeverity enumerates diagnostic severity levels.

const (
	// DIAGNOSTIC_SEVERITY_UNKNOWN is the default value when diagnostic severity is not specified.
	DiagnosticSeverity_DIAGNOSTIC_SEVERITY_UNKNOWN DiagnosticSeverity = 0
	// DIAGNOSTIC_SEVERITY_ERROR reports an error diagnostic.
	DiagnosticSeverity_DIAGNOSTIC_SEVERITY_ERROR DiagnosticSeverity = 1
	// DIAGNOSTIC_SEVERITY_WARNING reports a warning diagnostic.
	DiagnosticSeverity_DIAGNOSTIC_SEVERITY_WARNING DiagnosticSeverity = 2
	// DIAGNOSTIC_SEVERITY_INFORMATION reports an informational diagnostic.
	DiagnosticSeverity_DIAGNOSTIC_SEVERITY_INFORMATION DiagnosticSeverity = 3
	// DIAGNOSTIC_SEVERITY_HINT reports a hint diagnostic.
	DiagnosticSeverity_DIAGNOSTIC_SEVERITY_HINT DiagnosticSeverity = 4
)

func (DiagnosticSeverity) Descriptor

func (DiagnosticSeverity) Enum

func (DiagnosticSeverity) EnumDescriptor deprecated

func (DiagnosticSeverity) EnumDescriptor() ([]byte, []int)

Deprecated: Use DiagnosticSeverity.Descriptor instead.

func (DiagnosticSeverity) Number

func (DiagnosticSeverity) String

func (x DiagnosticSeverity) String() string

func (DiagnosticSeverity) Type

type FixRequest

type FixRequest struct {

	// file is a workspace- or service-relative source file path.
	File string `protobuf:"bytes,1,opt,name=file,proto3" json:"file,omitempty"`
	// contains filtered or unexported fields
}

FixRequest asks the agent to format or auto-fix one file.

func (*FixRequest) Descriptor deprecated

func (*FixRequest) Descriptor() ([]byte, []int)

Deprecated: Use FixRequest.ProtoReflect.Descriptor instead.

func (*FixRequest) GetFile

func (x *FixRequest) GetFile() string

func (*FixRequest) ProtoMessage

func (*FixRequest) ProtoMessage()

func (*FixRequest) ProtoReflect

func (x *FixRequest) ProtoReflect() protoreflect.Message

func (*FixRequest) Reset

func (x *FixRequest) Reset()

func (*FixRequest) String

func (x *FixRequest) String() string

type FixResponse

type FixResponse struct {

	// success is true when the requested operation completed successfully.
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// content is the file content after formatting; it may be empty when unchanged.
	Content string `protobuf:"bytes,2,opt,name=content,proto3" json:"content,omitempty"`
	// error explains why the operation failed; empty means success at this layer.
	Error string `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
	// actions names formatters or fixers executed by the agent.
	Actions []string `protobuf:"bytes,4,rep,name=actions,proto3" json:"actions,omitempty"`
	// contains filtered or unexported fields
}

FixResponse returns the fixed content and the formatter actions that ran.

func (*FixResponse) Descriptor deprecated

func (*FixResponse) Descriptor() ([]byte, []int)

Deprecated: Use FixResponse.ProtoReflect.Descriptor instead.

func (*FixResponse) GetActions

func (x *FixResponse) GetActions() []string

func (*FixResponse) GetContent

func (x *FixResponse) GetContent() string

func (*FixResponse) GetError

func (x *FixResponse) GetError() string

func (*FixResponse) GetSuccess

func (x *FixResponse) GetSuccess() bool

func (*FixResponse) ProtoMessage

func (*FixResponse) ProtoMessage()

func (*FixResponse) ProtoReflect

func (x *FixResponse) ProtoReflect() protoreflect.Message

func (*FixResponse) Reset

func (x *FixResponse) Reset()

func (*FixResponse) String

func (x *FixResponse) String() string

type GetProjectInfoRequest

type GetProjectInfoRequest struct {
	// contains filtered or unexported fields
}

GetProjectInfoRequest identifies the project info data to retrieve.

func (*GetProjectInfoRequest) Descriptor deprecated

func (*GetProjectInfoRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetProjectInfoRequest.ProtoReflect.Descriptor instead.

func (*GetProjectInfoRequest) ProtoMessage

func (*GetProjectInfoRequest) ProtoMessage()

func (*GetProjectInfoRequest) ProtoReflect

func (x *GetProjectInfoRequest) ProtoReflect() protoreflect.Message

func (*GetProjectInfoRequest) Reset

func (x *GetProjectInfoRequest) Reset()

func (*GetProjectInfoRequest) String

func (x *GetProjectInfoRequest) String() string

type GetProjectInfoResponse

type GetProjectInfoResponse struct {

	// module is the Codefly module name that groups services.
	Module string `protobuf:"bytes,1,opt,name=module,proto3" json:"module,omitempty"`
	// language is the implementation language reported by tooling or project metadata.
	Language string `protobuf:"bytes,2,opt,name=language,proto3" json:"language,omitempty"`
	// language_version is the detected toolchain/runtime version.
	LanguageVersion string `protobuf:"bytes,3,opt,name=language_version,json=languageVersion,proto3" json:"language_version,omitempty"`
	// packages are language packages or modules discovered in the project.
	Packages []*PackageInfo `protobuf:"bytes,4,rep,name=packages,proto3" json:"packages,omitempty"`
	// dependencies are packages or services required by this resource.
	Dependencies []*Dependency `protobuf:"bytes,5,rep,name=dependencies,proto3" json:"dependencies,omitempty"`
	// file_hashes maps source paths to hashes for change detection.
	FileHashes map[string]string `` /* 165-byte string literal not displayed */
	// error explains why the operation failed; empty means success at this layer.
	Error string `protobuf:"bytes,7,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

GetProjectInfoResponse returns language metadata useful for ingestion and planning.

func (*GetProjectInfoResponse) Descriptor deprecated

func (*GetProjectInfoResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetProjectInfoResponse.ProtoReflect.Descriptor instead.

func (*GetProjectInfoResponse) GetDependencies

func (x *GetProjectInfoResponse) GetDependencies() []*Dependency

func (*GetProjectInfoResponse) GetError

func (x *GetProjectInfoResponse) GetError() string

func (*GetProjectInfoResponse) GetFileHashes

func (x *GetProjectInfoResponse) GetFileHashes() map[string]string

func (*GetProjectInfoResponse) GetLanguage

func (x *GetProjectInfoResponse) GetLanguage() string

func (*GetProjectInfoResponse) GetLanguageVersion

func (x *GetProjectInfoResponse) GetLanguageVersion() string

func (*GetProjectInfoResponse) GetModule

func (x *GetProjectInfoResponse) GetModule() string

func (*GetProjectInfoResponse) GetPackages

func (x *GetProjectInfoResponse) GetPackages() []*PackageInfo

func (*GetProjectInfoResponse) ProtoMessage

func (*GetProjectInfoResponse) ProtoMessage()

func (*GetProjectInfoResponse) ProtoReflect

func (x *GetProjectInfoResponse) ProtoReflect() protoreflect.Message

func (*GetProjectInfoResponse) Reset

func (x *GetProjectInfoResponse) Reset()

func (*GetProjectInfoResponse) String

func (x *GetProjectInfoResponse) String() string

type LintRequest

type LintRequest struct {

	// file is a workspace- or service-relative source file path.
	File string `protobuf:"bytes,1,opt,name=file,proto3" json:"file,omitempty"` // optional: restrict to file
	// contains filtered or unexported fields
}

LintRequest asks the agent to run native linting, optionally scoped to one file.

func (*LintRequest) Descriptor deprecated

func (*LintRequest) Descriptor() ([]byte, []int)

Deprecated: Use LintRequest.ProtoReflect.Descriptor instead.

func (*LintRequest) GetFile

func (x *LintRequest) GetFile() string

func (*LintRequest) ProtoMessage

func (*LintRequest) ProtoMessage()

func (*LintRequest) ProtoReflect

func (x *LintRequest) ProtoReflect() protoreflect.Message

func (*LintRequest) Reset

func (x *LintRequest) Reset()

func (*LintRequest) String

func (x *LintRequest) String() string

type LintResponse

type LintResponse struct {

	// success is true when the requested operation completed successfully.
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// output is raw command, build, lint, or test output preserved for diagnostics.
	Output string `protobuf:"bytes,2,opt,name=output,proto3" json:"output,omitempty"`
	// diagnostics are compiler, linter, or language-server findings.
	Diagnostics []*Diagnostic `protobuf:"bytes,3,rep,name=diagnostics,proto3" json:"diagnostics,omitempty"`
	// contains filtered or unexported fields
}

LintResponse returns linter output and structured diagnostics.

func (*LintResponse) Descriptor deprecated

func (*LintResponse) Descriptor() ([]byte, []int)

Deprecated: Use LintResponse.ProtoReflect.Descriptor instead.

func (*LintResponse) GetDiagnostics

func (x *LintResponse) GetDiagnostics() []*Diagnostic

func (*LintResponse) GetOutput

func (x *LintResponse) GetOutput() string

func (*LintResponse) GetSuccess

func (x *LintResponse) GetSuccess() bool

func (*LintResponse) ProtoMessage

func (*LintResponse) ProtoMessage()

func (*LintResponse) ProtoReflect

func (x *LintResponse) ProtoReflect() protoreflect.Message

func (*LintResponse) Reset

func (x *LintResponse) Reset()

func (*LintResponse) String

func (x *LintResponse) String() string

type ListDependenciesRequest

type ListDependenciesRequest struct {
	// contains filtered or unexported fields
}

ListDependenciesRequest carries optional filters for listing dependencies.

func (*ListDependenciesRequest) Descriptor deprecated

func (*ListDependenciesRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListDependenciesRequest.ProtoReflect.Descriptor instead.

func (*ListDependenciesRequest) ProtoMessage

func (*ListDependenciesRequest) ProtoMessage()

func (*ListDependenciesRequest) ProtoReflect

func (x *ListDependenciesRequest) ProtoReflect() protoreflect.Message

func (*ListDependenciesRequest) Reset

func (x *ListDependenciesRequest) Reset()

func (*ListDependenciesRequest) String

func (x *ListDependenciesRequest) String() string

type ListDependenciesResponse

type ListDependenciesResponse struct {

	// dependencies are packages or services required by this resource.
	Dependencies []*Dependency `protobuf:"bytes,1,rep,name=dependencies,proto3" json:"dependencies,omitempty"`
	// error explains why the operation failed; empty means success at this layer.
	Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

ListDependenciesResponse returns dependencies discovered by the native package manager.

func (*ListDependenciesResponse) Descriptor deprecated

func (*ListDependenciesResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListDependenciesResponse.ProtoReflect.Descriptor instead.

func (*ListDependenciesResponse) GetDependencies

func (x *ListDependenciesResponse) GetDependencies() []*Dependency

func (*ListDependenciesResponse) GetError

func (x *ListDependenciesResponse) GetError() string

func (*ListDependenciesResponse) ProtoMessage

func (*ListDependenciesResponse) ProtoMessage()

func (*ListDependenciesResponse) ProtoReflect

func (x *ListDependenciesResponse) ProtoReflect() protoreflect.Message

func (*ListDependenciesResponse) Reset

func (x *ListDependenciesResponse) Reset()

func (*ListDependenciesResponse) String

func (x *ListDependenciesResponse) String() string

type PackageInfo

type PackageInfo struct {

	// name is the language-level package or module name.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// relative_path is the package directory relative to the service root.
	RelativePath string `protobuf:"bytes,2,opt,name=relative_path,json=relativePath,proto3" json:"relative_path,omitempty"`
	// files are source files that belong to this package.
	Files []string `protobuf:"bytes,3,rep,name=files,proto3" json:"files,omitempty"`
	// imports are direct imports declared by the package.
	Imports []string `protobuf:"bytes,4,rep,name=imports,proto3" json:"imports,omitempty"`
	// doc is package-level documentation from source comments.
	Doc string `protobuf:"bytes,5,opt,name=doc,proto3" json:"doc,omitempty"`
	// contains filtered or unexported fields
}

PackageInfo describes one language package or module in the project.

func (*PackageInfo) Descriptor deprecated

func (*PackageInfo) Descriptor() ([]byte, []int)

Deprecated: Use PackageInfo.ProtoReflect.Descriptor instead.

func (*PackageInfo) GetDoc

func (x *PackageInfo) GetDoc() string

func (*PackageInfo) GetFiles

func (x *PackageInfo) GetFiles() []string

func (*PackageInfo) GetImports

func (x *PackageInfo) GetImports() []string

func (*PackageInfo) GetName

func (x *PackageInfo) GetName() string

func (*PackageInfo) GetRelativePath

func (x *PackageInfo) GetRelativePath() string

func (*PackageInfo) ProtoMessage

func (*PackageInfo) ProtoMessage()

func (*PackageInfo) ProtoReflect

func (x *PackageInfo) ProtoReflect() protoreflect.Message

func (*PackageInfo) Reset

func (x *PackageInfo) Reset()

func (*PackageInfo) String

func (x *PackageInfo) String() string

type RemoveDependencyRequest

type RemoveDependencyRequest struct {

	// package_name is the package or dependency identifier used by the native manager.
	PackageName string `protobuf:"bytes,1,opt,name=package_name,json=packageName,proto3" json:"package_name,omitempty"`
	// contains filtered or unexported fields
}

RemoveDependencyRequest identifies a package to remove with the native package manager.

func (*RemoveDependencyRequest) Descriptor deprecated

func (*RemoveDependencyRequest) Descriptor() ([]byte, []int)

Deprecated: Use RemoveDependencyRequest.ProtoReflect.Descriptor instead.

func (*RemoveDependencyRequest) GetPackageName

func (x *RemoveDependencyRequest) GetPackageName() string

func (*RemoveDependencyRequest) ProtoMessage

func (*RemoveDependencyRequest) ProtoMessage()

func (*RemoveDependencyRequest) ProtoReflect

func (x *RemoveDependencyRequest) ProtoReflect() protoreflect.Message

func (*RemoveDependencyRequest) Reset

func (x *RemoveDependencyRequest) Reset()

func (*RemoveDependencyRequest) String

func (x *RemoveDependencyRequest) String() string

type RemoveDependencyResponse

type RemoveDependencyResponse struct {

	// success is true when the requested operation completed successfully.
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// error explains why the operation failed; empty means success at this layer.
	Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

RemoveDependencyResponse reports whether the package manager removed the dependency.

func (*RemoveDependencyResponse) Descriptor deprecated

func (*RemoveDependencyResponse) Descriptor() ([]byte, []int)

Deprecated: Use RemoveDependencyResponse.ProtoReflect.Descriptor instead.

func (*RemoveDependencyResponse) GetError

func (x *RemoveDependencyResponse) GetError() string

func (*RemoveDependencyResponse) GetSuccess

func (x *RemoveDependencyResponse) GetSuccess() bool

func (*RemoveDependencyResponse) ProtoMessage

func (*RemoveDependencyResponse) ProtoMessage()

func (*RemoveDependencyResponse) ProtoReflect

func (x *RemoveDependencyResponse) ProtoReflect() protoreflect.Message

func (*RemoveDependencyResponse) Reset

func (x *RemoveDependencyResponse) Reset()

func (*RemoveDependencyResponse) String

func (x *RemoveDependencyResponse) String() string

type TestRequest

type TestRequest struct {

	// path is a workspace- or service-relative filesystem path.
	Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"` // optional: restrict to package/file
	// verbose asks the native runner to retain more detailed output.
	Verbose bool `protobuf:"varint,2,opt,name=verbose,proto3" json:"verbose,omitempty"`
	// contains filtered or unexported fields
}

TestRequest asks the agent to run native tests, optionally scoped by path.

func (*TestRequest) Descriptor deprecated

func (*TestRequest) Descriptor() ([]byte, []int)

Deprecated: Use TestRequest.ProtoReflect.Descriptor instead.

func (*TestRequest) GetPath

func (x *TestRequest) GetPath() string

func (*TestRequest) GetVerbose

func (x *TestRequest) GetVerbose() bool

func (*TestRequest) ProtoMessage

func (*TestRequest) ProtoMessage()

func (*TestRequest) ProtoReflect

func (x *TestRequest) ProtoReflect() protoreflect.Message

func (*TestRequest) Reset

func (x *TestRequest) Reset()

func (*TestRequest) String

func (x *TestRequest) String() string

type TestResponse

type TestResponse struct {

	// success is true when the requested operation completed successfully.
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// output is raw command, build, lint, or test output preserved for diagnostics.
	Output string `protobuf:"bytes,2,opt,name=output,proto3" json:"output,omitempty"`
	// tests_run is the total number of tests executed.
	TestsRun int32 `protobuf:"varint,3,opt,name=tests_run,json=testsRun,proto3" json:"tests_run,omitempty"`
	// tests_passed is the number of tests that passed.
	TestsPassed int32 `protobuf:"varint,4,opt,name=tests_passed,json=testsPassed,proto3" json:"tests_passed,omitempty"`
	// tests_failed is the number of tests that failed.
	TestsFailed int32 `protobuf:"varint,5,opt,name=tests_failed,json=testsFailed,proto3" json:"tests_failed,omitempty"`
	// tests_skipped is the number of tests skipped by the runner.
	TestsSkipped int32 `protobuf:"varint,6,opt,name=tests_skipped,json=testsSkipped,proto3" json:"tests_skipped,omitempty"`
	// coverage_pct is the overall coverage percentage when available.
	CoveragePct float32 `protobuf:"fixed32,7,opt,name=coverage_pct,json=coveragePct,proto3" json:"coverage_pct,omitempty"`
	// failures are concise failing test names or messages.
	Failures []string `protobuf:"bytes,8,rep,name=failures,proto3" json:"failures,omitempty"`
	// contains filtered or unexported fields
}

TestResponse returns structured test counts and raw runner output.

func (*TestResponse) Descriptor deprecated

func (*TestResponse) Descriptor() ([]byte, []int)

Deprecated: Use TestResponse.ProtoReflect.Descriptor instead.

func (*TestResponse) GetCoveragePct

func (x *TestResponse) GetCoveragePct() float32

func (*TestResponse) GetFailures

func (x *TestResponse) GetFailures() []string

func (*TestResponse) GetOutput

func (x *TestResponse) GetOutput() string

func (*TestResponse) GetSuccess

func (x *TestResponse) GetSuccess() bool

func (*TestResponse) GetTestsFailed

func (x *TestResponse) GetTestsFailed() int32

func (*TestResponse) GetTestsPassed

func (x *TestResponse) GetTestsPassed() int32

func (*TestResponse) GetTestsRun

func (x *TestResponse) GetTestsRun() int32

func (*TestResponse) GetTestsSkipped

func (x *TestResponse) GetTestsSkipped() int32

func (*TestResponse) ProtoMessage

func (*TestResponse) ProtoMessage()

func (*TestResponse) ProtoReflect

func (x *TestResponse) ProtoReflect() protoreflect.Message

func (*TestResponse) Reset

func (x *TestResponse) Reset()

func (*TestResponse) String

func (x *TestResponse) String() string

type ToolingClient

type ToolingClient interface {
	// Code modification
	Fix(ctx context.Context, in *FixRequest, opts ...grpc.CallOption) (*FixResponse, error)
	// ApplyEdit applies a smart edit and optional language fixers.
	ApplyEdit(ctx context.Context, in *ApplyEditRequest, opts ...grpc.CallOption) (*ApplyEditResponse, error)
	// Dependency management
	ListDependencies(ctx context.Context, in *ListDependenciesRequest, opts ...grpc.CallOption) (*ListDependenciesResponse, error)
	// AddDependency installs a package through the native package manager.
	AddDependency(ctx context.Context, in *AddDependencyRequest, opts ...grpc.CallOption) (*AddDependencyResponse, error)
	// RemoveDependency removes a package through the native package manager.
	RemoveDependency(ctx context.Context, in *RemoveDependencyRequest, opts ...grpc.CallOption) (*RemoveDependencyResponse, error)
	// Analysis
	GetProjectInfo(ctx context.Context, in *GetProjectInfoRequest, opts ...grpc.CallOption) (*GetProjectInfoResponse, error)
	// Dev validation
	Build(ctx context.Context, in *BuildRequest, opts ...grpc.CallOption) (*BuildResponse, error)
	// Test runs native tests and returns structured counts.
	Test(ctx context.Context, in *TestRequest, opts ...grpc.CallOption) (*TestResponse, error)
	// Lint runs native linting and returns structured diagnostics.
	Lint(ctx context.Context, in *LintRequest, opts ...grpc.CallOption) (*LintResponse, error)
}

ToolingClient is the client API for Tooling service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Tooling provides command-oriented language operations. Every language agent (go-grpc, python-fastapi, etc.) implements this service.

NOTE: File operations (read, write, list, search) and git operations are NOT part of this service. Mind handles those directly via its VFS.

func NewToolingClient

func NewToolingClient(cc grpc.ClientConnInterface) ToolingClient

type ToolingServer

type ToolingServer interface {
	// Code modification
	Fix(context.Context, *FixRequest) (*FixResponse, error)
	// ApplyEdit applies a smart edit and optional language fixers.
	ApplyEdit(context.Context, *ApplyEditRequest) (*ApplyEditResponse, error)
	// Dependency management
	ListDependencies(context.Context, *ListDependenciesRequest) (*ListDependenciesResponse, error)
	// AddDependency installs a package through the native package manager.
	AddDependency(context.Context, *AddDependencyRequest) (*AddDependencyResponse, error)
	// RemoveDependency removes a package through the native package manager.
	RemoveDependency(context.Context, *RemoveDependencyRequest) (*RemoveDependencyResponse, error)
	// Analysis
	GetProjectInfo(context.Context, *GetProjectInfoRequest) (*GetProjectInfoResponse, error)
	// Dev validation
	Build(context.Context, *BuildRequest) (*BuildResponse, error)
	// Test runs native tests and returns structured counts.
	Test(context.Context, *TestRequest) (*TestResponse, error)
	// Lint runs native linting and returns structured diagnostics.
	Lint(context.Context, *LintRequest) (*LintResponse, error)
	// contains filtered or unexported methods
}

ToolingServer is the server API for Tooling service. All implementations must embed UnimplementedToolingServer for forward compatibility.

Tooling provides command-oriented language operations. Every language agent (go-grpc, python-fastapi, etc.) implements this service.

NOTE: File operations (read, write, list, search) and git operations are NOT part of this service. Mind handles those directly via its VFS.

type UnimplementedToolingServer

type UnimplementedToolingServer struct{}

UnimplementedToolingServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedToolingServer) AddDependency

func (UnimplementedToolingServer) ApplyEdit

func (UnimplementedToolingServer) Build

func (UnimplementedToolingServer) Fix

func (UnimplementedToolingServer) GetProjectInfo

func (UnimplementedToolingServer) Lint

func (UnimplementedToolingServer) ListDependencies

func (UnimplementedToolingServer) RemoveDependency

func (UnimplementedToolingServer) Test

type UnsafeToolingServer

type UnsafeToolingServer interface {
	// contains filtered or unexported methods
}

UnsafeToolingServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ToolingServer will result in compilation errors.

Directories

Path Synopsis

Jump to